@@ -201,10 +201,9 @@ class Revision(AnyEntity):
 
     def dc_title(self):
         if self.changeset:
-            return self._cw._('revision #%(rev)s:%(changeset)s') % {
+            return '#%(rev)s:%(changeset)s' % {
                 'rev': self.revision, 'changeset': self.changeset}
-        else:
-            return self._cw._('revision #%s') % self.revision
+        return '#%s' % self.revision
 
     def dc_long_title(self):
         try:
@@ -269,8 +268,15 @@ class VersionedFile(AnyEntity):
         return self.reverse_content_for
 
     @property
+    @cached
     def head(self):
-        return self.branch_head()
+        """return latest [deleted] version content for this file"""
+        rset = self._cw.execute(
+            'Any MAX(V) WHERE X eid %(x)s, V content_for X', {'x': self.eid})
+        # content_for relation is not mandatory on VersionedFile entities
+        if rset[0][0] is None:
+            return None
+        return rset.get_entity(0, 0)
 
     @cached
     def version_content(self, revnum):
@@ -416,18 +422,6 @@ class DeletedVersionContent(AnyEntity):
         nver = self.next_versions()
         return nver and nver[0] or None
 
-    def next_version(self, branch=_MARKER):
-        if branch is _MARKER:
-            branch = self.rev.branch
-        rset = self._cw.execute('Any NV,R,NVR,VF ORDERBY NVR ASC LIMIT 1 '
-                                'WHERE NV from_revision R, R revision NVR, '
-                                'R branch %(b)s, NV content_for VF, '
-                                'R revision > %(r)s, VF eid %(vf)s',
-                                {'r': self.rev.revision, 'b': branch,
-                                 'vf': self.file.eid})
-        if rset:
-            return rset.get_entity(0, 0)
-
     # < 0.7 bw compat properties
     @property
     def revision(self):
